@@ -2,7 +2,7 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2020 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
@@ -25,21 +25,22 @@
  The block below describes the properties of this module, and is read by
  the Projucer to automatically generate project code that uses it.
  For details about the syntax and how to create or use a module, see the
- JUCE Module Format.txt file.
+ JUCE Module Format.md file.
 
 
  BEGIN_JUCE_MODULE_DECLARATION
 
   ID:                 juce_core
   vendor:             juce
-  version:            5.4.7
+  version:            6.1.3
   name:               JUCE core classes
   description:        The essential set of basic JUCE classes, as required by all the other JUCE modules. Includes text, container, memory, threading and i/o functionality.
   website:            http://www.juce.com/juce
   license:            ISC
+  minimumCppStandard: 14
 
   dependencies:
-  OSXFrameworks:      Cocoa IOKit
+  OSXFrameworks:      Cocoa Foundation IOKit
   iOSFrameworks:      Foundation
   linuxLibs:          rt dl pthread
   mingwLibs:          uuid wsock32 wininet version ole32 ws2_32 oleaut32 imm32 comdlg32 shlwapi rpcrt4 winmm
@@ -64,9 +65,6 @@
 
 #include "system/juce_TargetPlatform.h"
 
-/** Debian specific constants
-  - Debian, we don't use embedded libraries
-*/
 #ifdef JUCE_INCLUDE_ZLIB_CODE
 # undef JUCE_INCLUDE_ZLIB_CODE
 #endif
@@ -91,8 +89,6 @@
 # undef JUCE_INCLUDE_PNGLIB_CODE
 #endif
 #define JUCE_INCLUDE_PNGLIB_CODE 0
-/** Debian specifics END
-*/
 
 //==============================================================================
 /** Config: JUCE_FORCE_DEBUG
@@ -207,6 +203,13 @@
  #define JUCE_STRICT_REFCOUNTEDPOINTER 0
 #endif
 
+/** Config: JUCE_ENABLE_ALLOCATION_HOOKS
+    If enabled, this will add global allocation functions with built-in assertions, which may
+    help when debugging allocations in unit tests.
+*/
+#ifndef JUCE_ENABLE_ALLOCATION_HOOKS
+ #define JUCE_ENABLE_ALLOCATION_HOOKS 0
+#endif
 
 #ifndef JUCE_STRING_UTF_TYPE
  #define JUCE_STRING_UTF_TYPE 8
@@ -247,19 +250,14 @@ namespace juce
 #include "memory/juce_Atomic.h"
 #include "text/juce_CharacterFunctions.h"
 
-#if JUCE_MSVC
- #pragma warning (push)
- #pragma warning (disable: 4514 4996)
-#endif
+JUCE_BEGIN_IGNORE_WARNINGS_MSVC (4514 4996)
 
 #include "text/juce_CharPointer_UTF8.h"
 #include "text/juce_CharPointer_UTF16.h"
 #include "text/juce_CharPointer_UTF32.h"
 #include "text/juce_CharPointer_ASCII.h"
 
-#if JUCE_MSVC
- #pragma warning (pop)
-#endif
+JUCE_END_IGNORE_WARNINGS_MSVC
 
 #include "text/juce_String.h"
 #include "text/juce_StringRef.h"
@@ -271,6 +269,7 @@ namespace juce
 #include "memory/juce_ReferenceCountedObject.h"
 #include "memory/juce_ScopedPointer.h"
 #include "memory/juce_OptionalScopedPointer.h"
+#include "containers/juce_ScopedValueSetter.h"
 #include "memory/juce_Singleton.h"
 #include "memory/juce_WeakReference.h"
 #include "threads/juce_ScopedLock.h"
@@ -286,10 +285,10 @@ namespace juce
 #include "containers/juce_ListenerList.h"
 #include "containers/juce_OwnedArray.h"
 #include "containers/juce_ReferenceCountedArray.h"
-#include "containers/juce_ScopedValueSetter.h"
 #include "containers/juce_SortedSet.h"
 #include "containers/juce_SparseSet.h"
 #include "containers/juce_AbstractFifo.h"
+#include "containers/juce_SingleThreadedAbstractFifo.h"
 #include "text/juce_NewLine.h"
 #include "text/juce_StringPool.h"
 #include "text/juce_Identifier.h"
@@ -300,6 +299,7 @@ namespace juce
 #include "text/juce_TextDiff.h"
 #include "text/juce_LocalisedStrings.h"
 #include "text/juce_Base64.h"
+#include "misc/juce_Functional.h"
 #include "misc/juce_Result.h"
 #include "misc/juce_Uuid.h"
 #include "misc/juce_ConsoleApplication.h"
@@ -318,6 +318,7 @@ namespace juce
 #include "streams/juce_InputSource.h"
 #include "files/juce_File.h"
 #include "files/juce_DirectoryIterator.h"
+#include "files/juce_RangedDirectoryIterator.h"
 #include "files/juce_FileInputStream.h"
 #include "files/juce_FileOutputStream.h"
 #include "files/juce_FileSearchPath.h"
@@ -364,9 +365,11 @@ namespace juce
 #include "zip/juce_ZipFile.h"
 #include "containers/juce_PropertySet.h"
 #include "memory/juce_SharedResourcePointer.h"
+#include "memory/juce_AllocationHooks.h"
+#include "memory/juce_Reservoir.h"
 
 #if JUCE_CORE_INCLUDE_OBJC_HELPERS && (JUCE_MAC || JUCE_IOS)
- #include "native/juce_osx_ObjCHelpers.h"
+ #include "native/juce_mac_ObjCHelpers.h"
 #endif
 
 #if JUCE_CORE_INCLUDE_COM_SMART_PTR && JUCE_WINDOWS
@@ -405,11 +408,9 @@ namespace juce
 }
 #endif
 
-#if JUCE_MSVC
- #pragma warning (pop)
+JUCE_END_IGNORE_WARNINGS_MSVC
 
- // In DLL builds, need to disable this warnings for other modules
- #if defined (JUCE_DLL_BUILD) || defined (JUCE_DLL)
-  #pragma warning (disable: 4251)
- #endif
+// In DLL builds, need to disable this warnings for other modules
+#if defined (JUCE_DLL_BUILD) || defined (JUCE_DLL)
+ JUCE_IGNORE_MSVC (4251)
 #endif
